@@ -45,16 +45,14 @@ func importMachine(cmd *cobra.Command, args []string) {
 		archive = strings.TrimSuffix(archive, ".age")
 		defer os.RemoveAll(archive)
 	}
+
+	if !strings.HasSuffix(archive, ".tar.gz") {
+		log.Fatal("unable to import: instance must be .age or .tar.gz file")
+	}
+
 	importName := strings.TrimSuffix(archive, ".tar.gz")
 	tempArchive := filepath.Join(userHomeDir, ".macpine", archive)
 
-	_, err = utils.CopyFile(archive, tempArchive)
-	if err != nil {
-		os.RemoveAll(tempArchive)
-		log.Fatal("unable to import: " + err.Error())
-	}
-	defer os.RemoveAll(tempArchive)
-
 	targetDir := strings.TrimSuffix(tempArchive, ".tar.gz")
 	exists, err := utils.DirExists(targetDir)
 	if err != nil {
@@ -63,15 +61,25 @@ func importMachine(cmd *cobra.Command, args []string) {
 	if exists {
 		log.Fatalf("unable to import: instance %s already exists\n", importName)
 	}
+
+	_, err = utils.CopyFile(archive, tempArchive)
+	if err != nil {
+		os.RemoveAll(tempArchive)
+		log.Fatal("unable to import: " + err.Error())
+	}
+	defer os.RemoveAll(tempArchive)
+
 	err = utils.Uncompress(tempArchive, targetDir)
 	if err != nil {
 		os.RemoveAll(targetDir)
+		os.RemoveAll(tempArchive)
 		log.Fatal("unable to import: " + err.Error())
 	}
 
 	machineConfig, err := qemu.GetMachineConfig(importName)
 	if err != nil {
 		os.RemoveAll(targetDir)
+		os.RemoveAll(tempArchive)
 		log.Fatal("unable to import: " + err.Error())
 	}
 
@@ -81,6 +89,7 @@ func importMachine(cmd *cobra.Command, args []string) {
 	err = qemu.SaveMachineConfig(machineConfig)
 	if err != nil {
 		os.RemoveAll(targetDir)
+		os.RemoveAll(tempArchive)
 		log.Fatal("unable to import: " + err.Error())
 	}
 }
