@@ -2,40 +2,32 @@ package cmd
 
 import (
 	"errors"
-	"io/ioutil"
 	"log"
-	"os"
-	"path/filepath"
 	"time"
 
 	"github.com/beringresearch/macpine/host"
 	"github.com/beringresearch/macpine/qemu"
 	"github.com/beringresearch/macpine/utils"
 	"github.com/spf13/cobra"
-	"gopkg.in/yaml.v3"
 )
 
 // stopCmd stops an Alpine instance
 var restartCmd = &cobra.Command{
-	Use:   "restart <instance> [<instance>...]",
-	Short: "Stop and start an instance.",
-	Run:   restart,
+	Use:     "restart <instance> [<instance>...]",
+	Short:   "Stop and start instances.",
+	Run:     restart,
+	Aliases: []string{"reboot"},
 
 	ValidArgsFunction:     host.AutoCompleteVMNamesOrTags,
 	DisableFlagsInUseLine: true,
 }
 
 func restart(cmd *cobra.Command, args []string) {
-	userHomeDir, err := os.UserHomeDir()
-	if err != nil {
-		log.Fatal(err)
-	}
-
 	if len(args) == 0 {
 		log.Fatal("missing instance name")
 	}
 
-	args, err = host.ExpandTagArguments(args)
+	args, err := host.ExpandTagArguments(args)
 	if err != nil {
 		log.Fatalln(err)
 	}
@@ -53,19 +45,7 @@ func restart(cmd *cobra.Command, args []string) {
 			continue
 		}
 
-		machineConfig := qemu.MachineConfig{}
-		config, err := ioutil.ReadFile(filepath.Join(userHomeDir, ".macpine", vmName, "config.yaml"))
-		if err != nil {
-			wasErr = true
-			log.Println(err)
-			continue
-		}
-		err = yaml.Unmarshal(config, &machineConfig)
-		if err != nil {
-			wasErr = true
-			log.Println(err)
-			continue
-		}
+		machineConfig, err := qemu.GetMachineConfig(vmName)
 
 		log.Println("restarting " + vmName + "...")
 		err = host.Stop(machineConfig)
