@@ -178,14 +178,7 @@ func (c *MachineConfig) Status() (string, int) {
 
 	if _, err := os.Stat(pidFile); err == nil {
 		status = "Running"
-		vmPID, err := os.ReadFile(pidFile)
-		if err != nil {
-			log.Fatalf("unable to read file: %v", err)
-		}
-
-		process := string(vmPID)
-		process = strings.TrimSuffix(process, "\n")
-		pid, _ = strconv.Atoi(process)
+		pid, _ = c.GetInstancePID()
 
 		// check if stopped and return "Paused"
 		cmd := exec.Command("ps", "-o", "stat=", "-p", strconv.Itoa(pid))
@@ -209,9 +202,18 @@ func (c *MachineConfig) Stop() error {
 			if procErr != nil {
 				return procErr
 			}
-			if err := p.Signal(syscall.SIGTERM); err != nil {
+
+			if err := p.Signal(syscall.SIGKILL); err != nil {
 				return err
 			}
+
+			pidFile := filepath.Join(c.Location, "alpine.pid")
+			sockFile := filepath.Join(c.Location, "alpine.sock")
+			qmpFile := filepath.Join(c.Location, "alpine.qmp")
+			os.Remove(pidFile)
+			os.Remove(sockFile)
+			os.Remove(qmpFile)
+
 			log.Println(c.Alias + " stopped")
 			return nil
 		} else {
@@ -254,7 +256,7 @@ func (c *MachineConfig) Resume() error {
 			if err := p.Signal(syscall.SIGCONT); err != nil {
 				return err
 			}
-			err := c.Exec("hwclock -w", true)
+			err := c.Exec("hwclock -s", true)
 			if err != nil {
 				log.Println("failed to synchonrize clock, instance system clock may be skewed")
 				return err
@@ -358,7 +360,7 @@ func (c *MachineConfig) Start() error {
 
 	cpuType := map[string]string{
 		"aarch64":      "cortex-a72",
-		"x86_64":       "qemu64",
+		"x86_64":       "qemu64,+avx,+avx2",
 		"x86_64_host":  "host" + hugePages,
 		"aarch64_host": "host"}
 
@@ -433,7 +435,7 @@ func (c *MachineConfig) Start() error {
 	}
 
 	log.Println("awaiting ssh server...")
-	err = c.Exec("hwclock -w", true) // root=true i.e. run as root
+	err = c.Exec("hwclock -s", true) // root=true i.e. run as root
 	if err != nil {
 		c.Stop()
 		c.CleanPIDFile()
@@ -617,6 +619,20 @@ func (c *MachineConfig) CleanPIDFile() {
 	}
 }
 
+func (c *MachineConfig) GetInstancePID() (int, error) {
+	pidFile := filepath.Join(c.Location, "alpine.pid")
+	vmPID, err := os.ReadFile(pidFile)
+	if err != nil {
+		return 0, err
+	}
+
+	process := string(vmPID)
+	process = strings.TrimSuffix(process, "\n")
+	pid, _ := strconv.Atoi(process)
+
+	return pid, nil
+}
+
 func GetMachineConfig(vmName string) (MachineConfig, error) {
 	machineConfig := MachineConfig{}
 
